/* -----------------------------
Internally used functions
----------------------------- */


/* force Enter to behave as Tab */
document.addEventListener('keydown', function (event) {
  if (event.keyCode === 13 && (event.target.nodeName === 'INPUT' || event.target.nodeName === 'SELECT')) {
    var form = event.target.form;
    var index = Array.prototype.indexOf.call(form, event.target);
    if (event.target.nodeName === 'SELECT')
	{
	  form.elements[index].blur();
	  form.elements[index].focus();
	}
	else
	{
	  form.elements[index + 1].focus();
	}
    event.preventDefault();
  }
});

/* Kludgy function to facilitate multi-line strings in Javascript */
function hereDoc(f) {
  return f.toString().
  replace(/^[^\/]+\/\*!?/, '').
  replace(/\*\/[^\/]+$/, '');
}

/* indexOf polyfill for IE */
if (!Array.prototype.indexOf) {
  Array.prototype.indexOf = function (searchElement /*, fromIndex */ ) {
    'use strict';
    if (this == null) {
      throw new TypeError();
    }
    var n, k, t = Object(this),
        len = t.length >>> 0;

    if (len === 0) {
      return -1;
    }
    n = 0;
    if (arguments.length > 1) {
      n = Number(arguments[1]);
      if (n != n) { // shortcut for verifying if it's NaN
        n = 0;
      } else if (n != 0 && n != Infinity && n != -Infinity) {
        n = (n > 0 || -1) * Math.floor(Math.abs(n));
      }
    }
    if (n >= len) {
      return -1;
    }
    for (k = n >= 0 ? n : Math.max(len - Math.abs(n), 0); k < len; k++) {
      if (k in t && t[k] === searchElement) {
        return k;
      }
    }
    return -1;
  };
}

/* forEach polyfill for IE */
if (window.NodeList && !NodeList.prototype.forEach) {
    NodeList.prototype.forEach = function (callback, thisArg) {
        thisArg = thisArg || window;
        for (var i = 0; i < this.length; i++) {
            callback.call(thisArg, this[i], i, this);
        }
    };
}

/* Gets URL parameters */
function getParam(name) {
  return decodeURIComponent((new RegExp('[?|&]' + name + '=' + '([^&;]+?)(&|#|;|$)').exec(location.search)||[,""])[1].replace(/\+/g, '%20'))||null
}

/* replace the innerHTML of an element (targeted by ID) */
function replaceInnerHTML(replaceID, replaceWith) {
  var e = document.getElementById(replaceID);
  if (e) e.innerHTML = replaceWith;
}

/* -----------------------------
All the other functions
----------------------------- */

slideLeftAppear = function(el) {
  el.style.display = 'block';
  el.style.left = '0';
  el.style.top = '0';
  // el.style['transition'] = 'left .2s ease-in-out';
  // Remove all existing active and previous views (there should only ever be 1)
  a_els = document.querySelectorAll('[data-view-active]');
  for (var i = 0; i < a_els.length; i++) {
    a_els[i].removeAttribute('data-view-active');
  }
  p_els = document.querySelectorAll('[data-view-previous]');
  for (var i = 0; i < p_els.length; i++) {
    p_els[i].removeAttribute('data-view-previous');
  }
  // Set previous view for "Back" buttons
  a_els[0].setAttribute('data-view-previous', '');
  // Set new active view
  el.setAttribute('data-view-active', '');
}

validateTrialForm = function (fields) {

  var name_regex = /^[\w ]+/;
  var email_regex = /^[a-z0-9!#$%&'*+/=?^_`{|}~-]+(?:\.[a-z0-9!#$%&'*+/=?^_`{|}~-]+)*@(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\.)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?$/;
  var ctr_st_regex = /[A-Z]{2}/;
  var phone_regex = /^[\s()+-]*([0-9][\s()+-]*){6,20}(?:[\-\.\ \\\/]?(?:#|ext\.?|extension|x)[\-\.\ \\\/]?(\d+))?$/i;

  var submit_btn = document.getElementById('btn_trial_activate');

  valid = true;

  fields.forEach(function (field) {
    // Validate name fields
    switch (field.getAttribute('data-validate-trial-info')) {
      case 'name':
        if (!name_regex.test(field.value.trim())) {
          valid = false;
          field.classList.add('invalid');
        } else {
          field.classList.remove('invalid', 'trial_invalid');
        }
        break;
      case 'email':
        if (!email_regex.test(field.value.trim())) {
          valid = false;
          field.classList.add('invalid');
        } else {
          field.classList.remove('invalid', 'trial_invalid');
        }
        break;
	  case 'phone':
	    if (field.value != "" && !phone_regex.test(field.value.trim())) {
          valid = false;
          field.classList.add('invalid');
        } else {
          field.classList.remove('invalid', 'trial_invalid');
        }
        break;
      case 'country':
        if (!ctr_st_regex.test(field.value)) {
          valid = false;
          field.classList.add('invalid');
        } else {
          field.classList.remove('invalid', 'trial_invalid');
        }
        break;
      case 'state':
        if (document.getElementById('trial_country').value == 'US' ||
          document.getElementById('trial_country').value == 'CA') {
          if (!ctr_st_regex.test(field.value)) {
            valid = false;
            field.classList.add('invalid');
          } else {
            field.classList.remove('invalid', 'trial_invalid');
          }
        }
        break;
      case 'consent_checkbox':
        if (!field.checked) {
          valid = false;
          field.classList.add('invalid');
        } else {
          field.classList.remove('invalid');
          if (field.name == 'privacyOptIn') {
            // Checking to see if we should visually notify of invalid required fields
            invalids = document.getElementsByClassName('invalid');
            var i, L = invalids.length - 1;
            for (i = L; i >= 0; i--) {
              invalids[i].classList.add('trial_invalid');
              invalids[i].classList.remove('invalid');
            }
          }
        }
        break;
      case 'consent_optional':
        break;
      case 'exempt':
        break;
      default:
        valid = false;
    }
  });

  // set Submit button state
  submit_btn.disabled = (valid) ? false : true;
};

function showStateAndConsent() {

  // Show states if needed
  var country = document.getElementById('trial_country').value;
  var stateDiv = document.getElementById('trial_input_state');
  var stateSelect = document.getElementById('trial_state');

  // First clear any existing options
  var i, L = stateSelect.options.length - 1;
  for(i = L; i >= 0; i--) {
    stateSelect.remove(i);
  }

  if (country == 'US') {
    var stateArray = us_states;
  } else if (country == 'CA') {
    var stateArray = ca_states;
  }

  if (stateArray) {
    // make first value empty / default / disabled
    var empty = document.createElement("option");
    empty.text = " ";
    empty.value = "";
    empty.hidden = true;
    empty.selected = true;
    empty.disabled = true;
    stateSelect.appendChild(empty);
    // add all states
    for (var i = 0; i < stateArray.length; i++) {
      var opt = document.createElement('option');
      opt.value = stateArray[i][0];
      opt.innerHTML = stateArray[i][1];
      stateSelect.appendChild(opt);
    }
    stateDiv.style.display = 'block';
  } else {
    stateDiv.style.display = 'none';
  }

  // Show checkboxes if needed
  var showConsent = false;
  var checkboxes = document.getElementById('trial_consent');
  var consent_required = document.getElementById('trial_input_privacy_agree');
  var consent_optional = document.getElementById('trial_input_marketing_agree');
  for (var i = 0; i < consent_countries.length; i++) {
    if (country == consent_countries[i]) {
      showConsent = true;
      checkboxes.style.display = 'block';
      consent_required.dataset.validateTrialInfo = 'consent_checkbox';
      consent_optional.dataset.validateTrialInfo = 'consent_optional';
    }
  }
  if (!showConsent) {
    checkboxes.style.display = 'none';
    consent_required.dataset.validateTrialInfo = 'exempt';
    consent_optional.dataset.validateTrialInfo = 'exempt';
  }
}

function collectTrialData() {

  var prod = getParam('prod') ? getParam('prod') : 'va';

  var submit_form_POST_string = '';

  // Add hidden fields - product specific
  hp_params = elq_data[prod];
  submit_form_POST_string = Object.keys(hp_params)
    .map(function(k) {return encodeURIComponent(k) + '=' + encodeURIComponent(hp_params[k]);})
    .join('&');

  submit_form_POST_string += '&';

  // Add hidden fields - global
  gp_params = elq_data.global;
  submit_form_POST_string += Object.keys(gp_params)
    .map(function(k) {return encodeURIComponent(k) + '=' + encodeURIComponent(gp_params[k]);})
    .join('&');

  // Add visible fields
  var v_params = '';
  var trial_form = document.getElementById("a_trial_form");

  for (var i = 0; i < trial_form.length; i++ ) {
    // handle checkbox values properly
    var fNam = encodeURIComponent(trial_form.elements[i].name);
    if (trial_form.elements[i].type == 'checkbox') {
      // Required?
      if (trial_form.elements[i].dataset.validateTrialInfo == 'consent_checkbox' ||
          trial_form.elements[i].dataset.validateTrialInfo == 'consent_optional') {
        var cVal = trial_form.elements[i].checked ? 1 : 0;
      } else {
        var cVal = '';
      }
      submit_form_POST_string += '&' + fNam + '=' + cVal;
    }
    else if (trial_form.elements[i].type != 'submit') {
      var vVal = encodeURIComponent(trial_form.elements[i].value);
      submit_form_POST_string += '&' + fNam + '=' + vVal;
    }
  }

  // Add collected data to hidden field in form
  elq_send_post.data = submit_form_POST_string;

}

function PostFormData() {
  var postRequest = new XMLHttpRequest();
  postRequest.open('POST', elq_send_post.url);
  postRequest.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded');
  logToNative("URL: " + elq_send_post.url);
  logToNative("Data: " + elq_send_post.data);

  //postRequest.addEventListener('load', (event) => {
    //alert('Data sent and response loaded.');
  //});

  // Define what happens in case of error
  //postRequest.addEventListener('error', (event) => {
    //alert('An error occurred.');
  //});
  //if (!elq_send_post.dbg) {
    postRequest.send(elq_send_post.data);
  //} else {
  //  var dbg_data = { dbg: elq_send_post.data.split('&').join('\n') }
  //  console.log(dbg_data.dbg);
  //}
}

function InitNativeHandlers() {
  var commandIds = ["btn_trial_activate", "btn_trial_activateText", "btn_trial_close"];
  SetupNativeHandlers(commandIds, 'click');
}

function SetupNativeHandlers(Ids, type) {
  for (i = 0; i < Ids.length; i++) {
    try {
      var element = document.getElementById(Ids[i]);
      if (element) {
        element.addEventListener(type, function (event) {
          var id = event.target.id;
          var params = {
            id: id,
            type: type
          };
          sendToNative(id, params);
          event.stopPropagation();
        });
      }
    } catch (error) {
      console.log(Ids[i] + " does not exist");
    }
  }
}

function logToNative(log_message) {
  var message = {
    message: "va_global_log",
    log: log_message
  };
  try {
    window.chrome.webview.postMessage(message);
  } catch (error) {
    console.log("WebView2 unavailable, cannot send message to native application: " + JSON.stringify(message));
    window.location.href = "#VA_BROWSER_MSG#" + JSON.stringify(message);
  }
}

function sendToNative(command, params) {
  var message = {
    message: command,
    args: params
  };
  try {
    window.chrome.webview.postMessage(message);
  } catch (error) {
    console.log("WebView2 unavailable, cannot send message to native application: " + JSON.stringify(message));
    window.location.href = "#VA_BROWSER_MSG#" + JSON.stringify(message);
  }
}

function btnCloseFocusOut() {
  document.getElementById("btn_trial_close").focus();
}

/* -----------------------------
Data and config objects
----------------------------- */

us_states = [
  ['AL', 'Alabama'],
  ['AK', 'Alaska'],
  ['AS', 'American Samoa'],
  ['AZ', 'Arizona'],
  ['AR', 'Arkansas'],
  ['CA', 'California'],
  ['CO', 'Colorado'],
  ['CT', 'Connecticut'],
  ['DE', 'Delaware'],
  ['DC', 'District Of Columbia'],
  ['FL', 'Florida'],
  ['GA', 'Georgia'],
  ['GU', 'Guam'],
  ['HI', 'Hawaii'],
  ['ID', 'Idaho'],
  ['IL', 'Illinois'],
  ['IN', 'Indiana'],
  ['IA', 'Iowa'],
  ['KS', 'Kansas'],
  ['KY', 'Kentucky'],
  ['LA', 'Louisiana'],
  ['ME', 'Maine'],
  ['MD', 'Maryland'],
  ['MH', 'Marshall Islands'],
  ['MA', 'Massachusetts'],
  ['MI', 'Michigan'],
  ['MN', 'Minnesota'],
  ['MS', 'Mississippi'],
  ['MO', 'Missouri'],
  ['MT', 'Montana'],
  ['NE', 'Nebraska'],
  ['NV', 'Nevada'],
  ['NH', 'New Hampshire'],
  ['NJ', 'New Jersey'],
  ['NM', 'New Mexico'],
  ['NY', 'New York'],
  ['NC', 'North Carolina'],
  ['ND', 'North Dakota'],
  ['OH', 'Ohio'],
  ['OK', 'Oklahoma'],
  ['OR', 'Oregon'],
  ['PA', 'Pennsylvania'],
  ['PR', 'Puerto Rico'],
  ['RI', 'Rhode Island'],
  ['SC', 'South Carolina'],
  ['SD', 'South Dakota'],
  ['TN', 'Tennessee'],
  ['TX', 'Texas'],
  ['UT', 'Utah'],
  ['VT', 'Vermont'],
  ['VI', 'Virgin Islands'],
  ['VA', 'Virginia'],
  ['WA', 'Washington'],
  ['WV', 'West Virginia'],
  ['WI', 'Wisconsin'],
  ['WY', 'Wyoming'],
  ['AE', 'Armed Forces AE'],
  ['AP', 'Armed Forces AP']
];

consent_countries = ['AT', 'BE', 'BG', 'CA', 'HR', 'CY', 'CZ', 'DK', 'EE', 'FI', 'FR', 'DE', 'EL', 'GR', 'HU', 'IE', 'IT', 'LV', 'LT', 'LU', 'MT', 'NL', 'PL', 'PT', 'RO', 'SK', 'SI', 'ES', 'SE', 'GB'];

ca_states = [
  ['AB', 'Alberta'],
  ['BC', 'British Columbia'],
  ['MB', 'Manitoba'],
  ['NB', 'New Brunswick'],
  ['NF', 'Newfoundland'],
  ['NT', 'Northwest Territories'],
  ['NS', 'Nova Scotia'],
  ['NV', 'Nunavut'],
  ['ON', 'Ontario'],
  ['PE', 'Prince Edward Island'],
  ['QC', 'Quebec'],
  ['SK', 'Saskatchewan'],
  ['YT', 'Yukon']
];

elq_data = {
  global: {
    elqFormName: 'WTProductTrialv2',
    elqSiteId: '608',
    elqCampaignId: '',
    OrderType: 'Trial Download',
    Medium: 'Product',
    Campaign: 'In-product-trial-activation',
	ProdInterestArea: 'WT',
	ProdInterestArea_WT: '1',
	WebsiteSource: 'WhoteTomato',
	MarketingPermission: 'Yes',
    OS: navigator.userAgent,
    language: Intl.NumberFormat().resolvedOptions().locale
  },
  va: {
    Source: 'VisualAssist',
    Yourmessage: 'TRIAL-VA: In-product trial activation. (No message.)',
    Topic: 'VisualAssist-Trial'
  }
};

elq_send_post = {
  url: 'https://s608.t.eloqua.com/e/f2',
  data: '',
  dbg: false,
};
