﻿/*

loc_langs - the object holding all items that need localizations

In order for translations to work, in HTML source add an empty
<span> with a class set to "l_" PLUS the unique name of the
sub-object containing its translations.

For example, to translate "First name:" in HTML source, find (or
add) that sub-item in the loc_langs object below.  It already
exists with a name of "trialFirstName".  Therefore the <span> in
the HTML source should be assigned a class of "l_trialFirstName".
Example:

    <span class="l_trialFirstName"></span>

The span can be empty in the HTML source, as it is dynamically
populated by arrange.js on page load.

It's easy enough to add new translated strings.  Simply copy one
of the existing below, give it a unique name, and enter the
translated strings.  Then add the "l_" + unique name class to a
<span> everywhere the string should display in the HTML source.
*/

loc_supportedLangs = [
  "en", // English
  "ptb", // Portuguese (Brazilian)
  "de", // German
  "fr", // French
  "es", // Spanish
  "it", // Italian
  "ko", // Korean
  "jp", // Japanese
  "ch", // Chinese (Simplified)
  "cht" // Chinese (Traditional)
];

loc_langs = {

  captionTrialScreen1 : {
    en: 'Enter your information to activate your free trial.',
    ptb: 'Digite suas informações para ativar seu teste gratuito.',
    de: 'Geben Sie Ihre Daten ein, um Ihre kostenlose Testversion zu aktivieren.',
    fr: 'Entrez vos informations pour activer votre essai gratuit.',
    es: 'Introduzca sus datos para activar la prueba gratuita.',
    it: 'Inserite i vostri dati per attivare la prova gratuita.',
    ko: '무료 평가판을 활성화하려면 정보를 입력하십시오.',
    jp: '無料トライアルを開始するために、お客様の情報を入力してください。',
    ch: '输入你的信息以激活你的免费试用。',
    cht: '輸入您的信息以激活免費試用。'
  },

  trialFirstName : {
    en: 'First name:',
    ptb: 'Primeiro nome:',
    de: 'Vornamen:',
    fr: 'Prénom :',
    es: 'Nombre de pila:',
    it: 'Nome:',
    ko: '이름:',
    jp: 'ファーストネーム:',
    ch: '姓氏:',
    cht: '名：'
  },

  trialLastName : {
    en: 'Last name:',
    ptb: 'Sobrenome:',
    de: 'Nachname:',
    fr: 'Nom de famille :',
    es: 'Apellido:',
    it: 'Cognome:',
    ko: '성:',
    jp: 'ラストネーム:',
    ch: '姓氏:',
    cht: '姓：'
  },

  trialEmail : {
    en: 'Email address:',
    ptb: 'Endereço de e-mail:',
    de: 'E-Mail Adresse:',
    fr: 'Adresse électronique :',
    es: 'Correo electrónico:',
    it: 'Indirizzo e-mail:',
    ko: '이메일 주소:',
    jp: 'Eメールアドレス:',
    ch: '电子邮件地址:',
    cht: '電子郵件地址：'
  },
  
  trialPhone : {
    en: 'Phone:',
    ptb: 'Telefone:',
    de: 'Telefon:',
    fr: 'Téléphone :',
    es: 'Teléfono:',
    it: 'Telefono:',
    ko: '핸드폰:',
    jp: '電話:',
    ch: '电话:',
    cht: '電話：'
  },

  trialCompany : {
    en: 'Company:',
    ptb: 'Empresa:',
    de: 'Gesellschaft:',
    fr: 'Entreprise :',
    es: 'Empresa:',
    it: 'Azienda:',
    ko: '회사:',
    jp: '会社です:',
    ch: '公司:',
    cht: '公司：'
  },

  trialCountry : {
    en: 'Country:',
    ptb: 'País:',
    de: 'Land:',
    fr: 'Pays :',
    es: 'País:',
    it: 'Paese:',
    ko: '국가:',
    jp: '国名:',
    ch: '国家:',
    cht: '國家：'
  },

  trialState : {
    en: 'State:',
    ptb: 'Estado:',
    de: 'Staat:',
    fr: 'État :',
    es: 'Estado:',
    it: 'Stato:',
    ko: '상태:',
    jp: '状態です:',
    ch: '州:',
    cht: '狀態：'
  },

  trialMarketingAgree : {
    en: 'I agree to receive Whole Tomato marketing communications via email.',
    ptb: 'Eu concordo em receber comunicações de marketing Whole Tomato via e-mail.',
    de: 'Ich stimme zu, dass ich Whole Tomato Marketing-Mitteilungen per E-Mail erhalte.',
    fr: 'J\'accepte de recevoir les communications marketing d\'Whole Tomato par e-mail.',
    es: 'Acepto recibir comunicaciones de marketing de Whole Tomato por correo electrónico.',
    it: 'Accetto di ricevere le comunicazioni di marketing di Whole Tomato via e-mail.',
    ko: '이메일을 통해 Whole Tomato 마케팅 커뮤니케이션 수신에 동의합니다.',
    jp: '私は、Whole Tomatoのマーケティングコミュニケーションを電子メールで受信することに同意します。',
    ch: '我同意通过电子邮件接收Whole Tomato的营销信息。',
    cht: '我同意通過電子郵件接收 Whole Tomato 營銷通訊。'
  },

  trialPrivacyAgree : {
    en: 'I have read, understand and agree to Whole Tomato\'s <a href="app:2000@https://www.ideracorp.com/legal/WholeTomato">terms and conditions</a> and <a href="app:2000@https://www.ideracorp.com/Legal/PrivacyShield">privacy statement</a>.',
    ptb: 'Eu li, entendi e concordo com o Whole Tomato <a href="app:2000@https://www.ideracorp.com/legal/WholeTomato">termos e condições</a> e <a href="app:2000@https://www.ideracorp.com/Legal/PrivacyShield">declaração de privacidade</a>.',
    de: 'Ich habe die Whole Tomato\'s gelesen, verstanden und stimme ihnen zu <a href="app:2000@https://www.ideracorp.com/legal/WholeTomato">Bedingungen und Konditionen</a> und <a href="app:2000@https://www.ideracorp.com/Legal/PrivacyShield">Erklärung zum Datenschutz</a>.',
    fr: 'J\'ai lu, compris et accepté les conditions générales d\'Whole Tomato <a href="app:2000@https://www.ideracorp.com/legal/WholeTomato">conditions générales</a> et <a href="app:2000@https://www.ideracorp.com/Legal/PrivacyShield">déclaration de confidentialité</a>.',
    es: 'He leído, entiendo y estoy de acuerdo con Whole Tomato\'s <a href="app:2000@https://www.ideracorp.com/legal/WholeTomato">condiciones generales</a> y <a href="app:2000@https://www.ideracorp.com/Legal/PrivacyShield">declaración de privacidad</a>.',
    it: 'Ho letto, compreso e accettato le condizioni di Whole Tomato <a href="app:2000@https://www.ideracorp.com/legal/WholeTomato">termini e condizioni</a> e <a href="app:2000@https://www.ideracorp.com/Legal/PrivacyShield">dichiarazione sulla privacy</a>.',
    ko: 'Whole Tomato의 내용을 읽고 이해했으며 이에 동의합니다. <a href="app:2000@https://www.ideracorp.com/legal/WholeTomato">이용 약관</a> 그리고 <a href="app:2000@https://www.ideracorp.com/Legal/PrivacyShield">개인 정보 보호 정책</a>.',
    jp: '私は、Whole Tomatoの以下の項目を読み、理解し、同意します <a href="app:2000@https://www.ideracorp.com/legal/WholeTomato">諸条件</a> と <a href="app:2000@https://www.ideracorp.com/Legal/PrivacyShield">プライバシーステートメント</a>.',
    ch: '我已经阅读，理解并同意Whole Tomato的 <a href="app:2000@https://www.ideracorp.com/legal/WholeTomato">条款和条件</a> 和 <a href="app:2000@https://www.ideracorp.com/Legal/PrivacyShield">隐私声明</a>.',
    cht: '我已閱讀、理解並同意 Whole Tomato 的 <a href="app:2000@https://www.ideracorp.com/legal/WholeTomato">條款和條件</a> 和 <a href="app:2000@https://www.ideracorp.com/Legal/PrivacyShield">隱私聲明</a>.'
  },

  trialPrivacyText : {
    en: 'By registering, you consent to the processing of your personal data by Whole Tomato as described in the <a href="app:2000@https://www.ideracorp.com/Legal/PrivacyShield">privacy statement</a>. Whole Tomato Software, LLC is part of the Idera group and may share your information with its parent company Idera, Inc., and its affiliates. For further details on how your data is used, stored, and shared, please review our <a href="app:2000@https://www.ideracorp.com/Legal/PrivacyShield">privacy statement</a>.',
    ptb: 'Ao registrar-se, você consente com o processamento de seus dados pessoais pelo Whole Tomato, conforme descrito no <a href="app:2000@https://www.ideracorp.com/Legal/PrivacyShield">declaração de privacidade</a>. Whole Tomato Software, LLC faz parte do grupo Idera e pode compartilhar suas informações com sua matriz Idera, Inc., e suas afiliadas. Para mais detalhes sobre como seus dados são usados, armazenados e compartilhados, por favor, revise nossa <a href="app:2000@https://www.ideracorp.com/Legal/PrivacyShield">declaração de privacidade</a>.',
    de: 'Mit der Registrierung stimmen Sie der Verarbeitung Ihrer persönlichen Daten durch Whole Tomato zu, wie sie in der <a href="app:2000@https://www.ideracorp.com/Legal/PrivacyShield">Erklärung zum Datenschutz</a>. Whole Tomato Software, LLC ist Teil der Idera-Gruppe und kann Ihre Daten mit der Muttergesellschaft Idera, Inc. und deren Tochtergesellschaften teilen. Weitere Einzelheiten darüber, wie Ihre Daten verwendet, gespeichert und weitergegeben werden, finden Sie in unserer <a href="app:2000@https://www.ideracorp.com/Legal/PrivacyShield">Erklärung zum Datenschutz</a>.',
    fr: 'En vous inscrivant, vous consentez au traitement de vos données personnelles par Whole Tomato, tel que décrit dans les conditions générales de vente. <a href="app:2000@https://www.ideracorp.com/Legal/PrivacyShield">déclaration de confidentialité</a>. Whole Tomato Software, LLC fait partie du groupe Idera et peut partager vos informations avec sa société mère Idera, Inc. et ses affiliés. Pour plus de détails sur la façon dont vos données sont utilisées, stockées et partagées, veuillez consulter notre site Web <a href="app:2000@https://www.ideracorp.com/Legal/PrivacyShield">déclaration de confidentialité</a>.',
    es: 'Al registrarse, da su consentimiento al tratamiento de sus datos personales por parte de Whole Tomato tal como se describe en el <a href="app:2000@https://www.ideracorp.com/Legal/PrivacyShield">declaración de privacidad</a>. Whole Tomato Software, LLC forma parte del grupo Idera y puede compartir su información con su empresa matriz Idera, Inc. y sus filiales. Para obtener más información sobre cómo se utilizan, almacenan y comparten sus datos, consulte nuestra <a href="app:2000@https://www.ideracorp.com/Legal/PrivacyShield">declaración de privacidad</a>.',
    it: 'Registrandosi, l\'utente acconsente al trattamento dei propri dati personali da parte di Whole Tomato, come descritto nella sezione "Informazioni" <a href="app:2000@https://www.ideracorp.com/Legal/PrivacyShield">dichiarazione sulla privacy</a>. Whole Tomato Software, LLC fa parte del gruppo Idera e può condividere i vostri dati con la società madre Idera, Inc. e le sue affiliate. Per ulteriori dettagli sulle modalità di utilizzo, archiviazione e condivisione dei vostri dati, vi invitiamo a consultare il nostro sito web <a href="app:2000@https://www.ideracorp.com/Legal/PrivacyShield">dichiarazione sulla privacy</a>.',
    ko: '등록함으로써 귀하는 Whole Tomato가 귀하의 개인 데이터를 처리하는 데 동의하는 것입니다 <a href="app:2000@https://www.ideracorp.com/Legal/PrivacyShield">개인 정보 보호 정책</a>. Whole Tomato Software, LLC는 Idera 그룹의 일부이며 귀하의 정보를 모회사인 Idera, Inc. 및 계열사와 공유할 수 있습니다. 귀하의 데이터가 사용, 저장 및 공유되는 방법에 대한 자세한 내용은 당사를 검토하십시오 <a href="app:2000@https://www.ideracorp.com/Legal/PrivacyShield">개인 정보 보호 정책</a>.',
    jp: '登録することにより、お客様はWhole Tomatoがお客様の個人情報を以下のように取り扱うことに同意したものとみなされます <a href="app:2000@https://www.ideracorp.com/Legal/PrivacyShield">プライバシーステートメント</a>. Whole Tomato Software, LLCは、Ideraグループの一員であり、その親会社であるIdera, Inc.およびその関連会社とお客様の情報を共有する場合があります。お客様のデータがどのように使用、保存、共有されるかの詳細については、当社のウェブサイトをご覧ください <a href="app:2000@https://www.ideracorp.com/Legal/PrivacyShield">プライバシーステートメント</a>.',
    ch: '通过注册，你同意Whole Tomato对你的个人数据进行处理，如以下所述 <a href="app:2000@https://www.ideracorp.com/Legal/PrivacyShield">隐私声明</a>. Whole Tomato Software, LLC是Idera集团的一部分，可以和它的母公司Idera, Inc.及其附属机构分享你的信息。关于你的数据如何被使用，存储和共享的进一步细节，请查看我们的 <a href="app:2000@https://www.ideracorp.com/Legal/PrivacyShield">隐私声明</a>.',
    cht: '註冊即表示您同意 Whole Tomato 按照以下說明處理您的個人數據 <a href="app:2000@https://www.ideracorp.com/Legal/PrivacyShield">隱私聲明</a>. Whole Tomato Software, LLC 是 Idera 集團的一部分，可能會與其母公司 Idera, Inc. 及其附屬公司共享您的信息。 有關如何使用、存儲和共享您的數據的更多詳細信息，請查看我們的 <a href="app:2000@https://www.ideracorp.com/Legal/PrivacyShield">隱私聲明</a>.'
  },

  btnActivateTrial : {
    en: 'Activate trial',
    ptb: 'Ativar o julgamento',
    de: 'Versuch aktivieren',
    fr: 'Activer l\'essai',
    es: 'Activar prueba',
    it: 'Attivare la prova',
    ko: '평가판 활성화',
    jp: 'トライアルを開始する',
    ch: '激活试用',
    cht: '激活試用'
  },

  trialActivated : {
    en: 'Your trial is activated. You can close this window.',
    ptb: 'Seu julgamento é ativado. Você pode fechar esta janela.',
    de: 'Ihre Testversion ist aktiviert. Sie können dieses Fenster schließen.',
    fr: 'Votre essai est activé. Vous pouvez fermer cette fenêtre.',
    es: 'Su prueba está activada. Puede cerrar esta ventana.',
    it: 'La prova è stata attivata. È possibile chiudere questa finestra.',
    ko: '평가판이 활성화되었습니다. 이 창을 닫아도 됩니다.',
    jp: '試用が開始されました。このウィンドウを閉じることができます。',
    ch: '您的试用已经激活。你可以关闭这个窗口。',
    cht: '您的試用版已激活。 您可以關閉此窗口。'
  },

};
